@@ -8,7 +8,8 @@ from datetime import datetime
 from uuid import uuid4
 from requests.auth import HTTPBasicAuth, AuthBase
 from collections import OrderedDict
-from os.path import isfile
+from os import environ
+from os.path import exists, expanduser, isfile, join
 
 from requests.utils import to_native_string
 
@@ -155,35 +156,40 @@ class Auth(object):
     """Provides authentication for StormPath API requests."""
 
     def __init__(self, api_key_file_location=None,
-                 api_key_id_property_name='apiKey.id',
-                 api_key_secret_property_name='apiKey.secret',
-                 api_key=None, id=None, secret=None, scheme='SAuthc1',
-                 method=None):
+            api_key_file=None,
+            api_key_id_property_name='apiKey.id',
+            api_key_secret_property_name='apiKey.secret',
+            api_key=None, id=None, secret=None, scheme='SAuthc1',
+            api_key_id=None, api_key_secret=None,
+            method=None):
         """
         Initialize authentication using one of the available authentication
         credentials source:
 
-        :param api_key_file_location: Location of the API key file (in the
-            Java .properties file format) (default: API key file not used)
+        :param api_key_file: Location of the API key file (in the Java
+        .properties file format) (default: API key file not used)
         :param api_key_id_property_name: Name of the `ID` property in the
             key file (default: apiKey.id)
         :param api_key_secret_property_name: Name of the `secret` property
             in the key file (default: apiKey.secret)
         :param api_key: A dictionary-like object containing the `id` and
             `secret` keys mapped to the API ID and secret respectively
-        :param id: ID (if directly provided; default is None)
-        :param secret: secret (if directly provided; default is None)
+        :param api_key_id: ID (if directly provided; default is None)
+        :param api_key_secret: secret (if directly provided; default is None)
         :param scheme: authentication scheme (`Sauthc1` or `basic`, default is
             `Sauthc1`)
 
         All available authentication credentials sources are checked, in this
         priority:
 
-        1. API key file (if `api_key_file_location` is set and the file exists)
+        1. API key file (if `api_key_file` is set and the file exists)
         2. API key dict (if `api_key` contains `id` and `secret` keys)
-        3. API key `secret` and `id` parameters
+        3. API key `api_key_id` and `api_key_secret` parameters
+        4. STORMPATH_API_KEY_FILE as an environment variable.
+        4. STORMPATH_API_KEY_ID and STORMPATH_API_KEY_SECRET as environment
+           variables.
 
-        The `id` and `secret` can be accessed as attributes.
+        The `api_key_id` and `api_key_secret` can be accessed as attributes.
 
         The default authentication scheme is `Sauthc1`, and is strongly
         recommended. In cases where it can't be used (for example, in Google
@@ -193,30 +199,57 @@ class Auth(object):
         Once initialized, `scheme` property will return the authentication
         scheme implementation selected.
         """
-        self._id = None
-        self._secret = None
+        self._api_key_id = None
+        self._api_key_secret = None
         self._scheme = scheme
 
         # backwards compatibility, in case anyone used it
         if method is not None:
             self._scheme = 'basic' if method == 'basic' else 'SAuthc1'
 
-        if self._read_api_key_file(api_key_file_location,
+        if self._read_api_key_file(api_key_file or api_key_file_location,
                 api_key_id_property_name, api_key_secret_property_name):
             return
 
         if api_key and 'id' in api_key and 'secret' in api_key:
-            self._id = api_key['id']
-            self._secret = api_key['secret']
+            self._api_key_id = api_key['id']
+            self._api_key_secret = api_key['secret']
+
+            return
+
+        if api_key and 'api_key_id' in api_key and 'api_key_secret' in api_key:
+            self._api_key_id = api_key['api_key_id']
+            self._api_key_secret = api_key['api_key_secret']
 
             return
 
         if id and secret:
-            self._id = id
-            self._secret = secret
+            self._api_key_id = id
+            self._api_key_secret = secret
 
             return
 
+        if api_key_id and api_key_secret:
+            self._api_key_id = api_key_id
+            self._api_key_secret = api_key_secret
+
+            return
+
+        if self._read_api_key_file(environ.get('STORMPATH_API_KEY_FILE'),
+                api_key_id_property_name, api_key_secret_property_name):
+            return
+
+        if environ.get('STORMPATH_API_KEY_ID') and environ.get('STORMPATH_API_KEY_SECRET'):
+            self._api_key_id = environ.get('STORMPATH_API_KEY_ID')
+            self._api_key_secret = environ.get('STORMPATH_API_KEY_SECRET')
+
+            return
+
+        default_file = join(expanduser('~'), '.stormpath', 'apiKey.properties')
+        if exists(default_file) and self._read_api_key_file(default_file,
+                api_key_id_property_name, api_key_secret_property_name):
+            return
+
         raise ValueError('No valid authentication sources found')
 
     @staticmethod
@@ -243,21 +276,21 @@ class Auth(object):
 
     def _read_api_key_file(self, fname, id_name, secret_name):
         cred = self._load_properties(fname)
-        self._id = cred.get(id_name)
-        self._secret = cred.get(secret_name)
+        self._api_key_id = cred.get(id_name)
+        self._api_key_secret = cred.get(secret_name)
 
-        return (self._id and self._secret)
+        return (self._api_key_id and self._api_key_secret)
 
     def __call__(self):
         return self.signer
 
     @property
     def id(self):
-        return self._id
+        return self._api_key_id
 
     @property
     def secret(self):
-        return self._secret
+        return self._api_key_secret
 
     @property
     def basic(self):
@@ -267,7 +300,7 @@ class Auth(object):
 
         http://docs.stormpath.com/rest/product-guide/#authentication
         """
-        return HTTPBasicAuth(self._id, self._secret)
+        return HTTPBasicAuth(self._api_key_id, self._api_key_secret)
 
     @property
     def digest(self):
@@ -278,7 +311,7 @@ class Auth(object):
 
         http://docs.stormpath.com/rest/product-guide/#authentication
         """
-        return Sauthc1Signer(self._id, self._secret)
+        return Sauthc1Signer(self._api_key_id, self._api_key_secret)
 
     @property
     def signer(self):
