@@ -1,5 +1,7 @@
 """Live tests of client authentication against the Stormpath service API."""
 
+from os import environ
+
 from stormpath.client import Client
 from stormpath.error import Error
 
@@ -44,3 +46,7 @@ class TestAuth(LiveBase):
         with self.assertRaises(Error):
             list(client.applications)
 
+    def test_load_from_environment_variables(self):
+        client = Client()
+        for app in client.applications:
+            self.assertTrue(app.href)
